WindowsMidiDevice class
- Inheritance
-
- Object
- MidiDevice
- WindowsMidiDevice
Constructors
-
WindowsMidiDevice(String id, String name, StreamController<
MidiPacket> _rxStreamCtrl, StreamController<MidiSetupChange> _setupStreamController, int callbackAddress)
Properties
- callbackAddress ↔ int
-
getter/setter pair
- connected ↔ bool
-
getter/setter pairinherited
- connectionState → MidiConnectionState
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
hMidiInDevicePtr
→ Pointer<
Pointer< NativeType> > -
final
-
hMidiOutDevicePtr
→ Pointer<
Pointer< NativeType> > -
final
- id ↔ String
-
getter/setter pairinherited
-
inputPorts
↔ List<
MidiPort> -
getter/setter pairinherited
- isDisconnecting → bool
-
no setter
- name ↔ String
-
getter/setter pairinherited
-
onConnectionStateChanged
→ Stream<
MidiConnectionState> -
no setterinherited
-
outputPorts
↔ List<
MidiPort> -
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type ↔ MidiDeviceType
-
getter/setter pairinherited
Methods
-
addInput(
int id) → void -
addOutput(
int id) → void -
connect(
) → bool - Connect to the device, ie. open input and output ports NOTE: Currently only the first input/output port is considered
-
containsMidiIn(
int input) → dynamic -
disconnect(
) → bool -
dispose(
) → void -
inherited
-
handleData(
Uint8List data, int timestamp) → dynamic -
handleSysexData(
Uint8List data, Pointer< MIDIHDR> midiHdrPointer) → dynamic -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
send(
Uint8List data) → dynamic -
setConnectionState(
MidiConnectionState value) → void -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited